@@ -1,15 +1,15 @@
 import abc
 import datetime
-from typing import Union
+from typing import Optional
 
-from taskw_gcal_sync.utils import is_same_datetime
+from loguru import logger
+
+from taskw_gcal_sync.helpers import is_same_datetime
 
 
 class GenericSide(abc.ABC):
     """Interface for interacting with the various services."""
 
-    __metaclass__ = abc.ABCMeta
-
     def start(self):
         """Initialisation steps.
 
@@ -29,9 +29,11 @@ class GenericSide(abc.ABC):
         raise NotImplementedError("Implement in derived")
 
     @abc.abstractmethod
-    def get_single_item(self, item_id: str) -> Union[dict, None]:
+    def get_item(self, item_id: str, use_cached: bool = False) -> Optional[dict]:
         """Get a single item based on the given UUID.
 
+        :use_cached: False if you want to fetch the latest version of the item. True if a
+                     cached version would do.
         :returns: None if not found, the item in dict representation otherwise
         """
         raise NotImplementedError("Should be implemented in derived")
@@ -78,25 +80,31 @@ class GenericSide(abc.ABC):
         """
 
         for k in keys:
-            if k in item1 and k in item2:
-                if isinstance(item1[k], datetime.datetime) and isinstance(
-                    item2[k], datetime.datetime
-                ):
-
-                    if is_same_datetime(item1[k], item2[k]):
-                        continue
-                    else:
-                        return False
-
-                else:
-                    if item1[k] == item2[k]:
-                        continue
-                    else:
-                        return False
-
-            elif k not in item1 and k not in item2:
+            if k not in item1 and k not in item2:
                 continue
-            else:
+
+            if (k in item1 and k not in item2) or (k not in item1 and k in item2):
                 return False
 
+            if isinstance(item1[k], datetime.datetime) and isinstance(
+                item2[k], datetime.datetime
+            ):
+                if is_same_datetime(item1[k], item2[k]):
+                    continue
+                else:
+                    logger.opt(lazy=True).trace(
+                        f"\n\nItems differ\n\nItem1\n\n{item1}\n\nItem2\n\n{item2}"
+                        f"\n\nKey [{k}] is different - [{repr(item1[k])}] | [{repr(item2[k])}]"
+                    )
+                    return False
+            else:
+                if item1[k] == item2[k]:
+                    continue
+                else:
+                    logger.opt(lazy=True).trace(
+                        f"\n\nItems differ\n\nItem1\n\n{item1}\n\nItem2\n\n{item2}"
+                        f"\n\nKey [{k}] is different - [{repr(item1[k])}] | [{repr(item2[k])}]"
+                    )
+                    return False
+
         return True
