@@ -1,18 +1,19 @@
-"""
-Various helper methods.
-
-"""
+"""Various helper methods."""
 
+import datetime
 import re
+from typing import Any
+
+import dateutil.tz
 
 
-def get_object_unique_name(obj):
+def get_object_unique_name(obj: Any) -> str:
     """Return a unique string associated with the given object.
 
     That string is constructed as follows: <object class name>_<object_hex_id>
     """
 
-    return "{}_{}".format(type(obj).__name__, hex(id(obj)))
+    return f"{type(obj).__name__}_{hex(id(obj))}"
 
 
 def xor(*args):
@@ -34,12 +35,12 @@ def xor(*args):
     return sum([bool(i) for i in args]) == 1
 
 
-def get_valid_filename(s) -> str:
+def get_valid_filename(s: str) -> str:
     """Return a filename-compatible version of the given string s
 
     :param s: String to be used as the base of the filename. You may also pass
-    non-string objects that will however be able to convert to strings via the
-    str operator.
+              non-string objects that will however be able to convert to strings via the
+              str operator.
 
     >>> get_valid_filename(r"5678^()^")
     '5678____'
@@ -49,8 +50,31 @@ def get_valid_filename(s) -> str:
     'strin___g'
 
     .. seealso::
-        - `https://stackoverflow.com/questions/295135/turn-a-string-into-a-valid-filename`_
 
+        `https://stackoverflow.com/questions/295135/turn-a-string-into-a-valid-filename`_
     """
     s = str(s).strip().replace(" ", "_")
     return re.sub(r"(?u)[^-\w.]", "_", s)
+
+
+def is_same_datetime(dt1: datetime.datetime, dt2: datetime.datetime) -> bool:
+    """Compare two datetime.datetime objects.
+
+    If the timezone is empty, assume local timezone
+    """
+
+    assert isinstance(dt1, datetime.datetime)
+    assert isinstance(dt2, datetime.datetime)
+
+    # if there is no timezone, assume local timezone
+    if dt1.tzinfo is None:
+        dt1_ = dt1.replace(tzinfo=dateutil.tz.tzlocal())
+    else:
+        dt1_ = dt1
+
+    if dt2.tzinfo is None:
+        dt2_ = dt2.replace(tzinfo=dateutil.tz.tzlocal())
+    else:
+        dt2_ = dt2
+
+    return dt1_ == dt2_
